summaryrefslogtreecommitdiffstats
path: root/lib/libchmfile/libchmfile.h
diff options
context:
space:
mode:
Diffstat (limited to 'lib/libchmfile/libchmfile.h')
-rw-r--r--lib/libchmfile/libchmfile.h56
1 files changed, 28 insertions, 28 deletions
diff --git a/lib/libchmfile/libchmfile.h b/lib/libchmfile/libchmfile.h
index ab129b5..f94de0b 100644
--- a/lib/libchmfile/libchmfile.h
+++ b/lib/libchmfile/libchmfile.h
@@ -22,22 +22,22 @@
#ifndef INCLUDE_LIBCHMFILE_H
#define INCLUDE_LIBCHMFILE_H
-#include <qstring.h>
-#include <qcstring.h>
-#include <qlistview.h>
-#include <qlistbox.h>
-#include <qmap.h>
-#include <qvaluevector.h>
-#include <qtextcodec.h>
+#include <tqstring.h>
+#include <tqcstring.h>
+#include <tqlistview.h>
+#include <tqlistbox.h>
+#include <tqmap.h>
+#include <tqvaluevector.h>
+#include <tqtextcodec.h>
#include "libchmtextencoding.h"
-// Qt3/Qt4 compatibility: in Qt3 QVector stores pointers, not values - so QValueVector should be used.
-// In Qt4 QVector stores values, so we can use QVector
-#if defined (USE_QT_4)
- #define QT34VECTOR QVector
+// TQt3/TQt4 compatibility: in TQt3 TQVector stores pointers, not values - so TQValueVector should be used.
+// In TQt4 TQVector stores values, so we can use TQVector
+#if defined (USE_TQT_4)
+ #define QT34VECTOR TQVector
#else
- #define QT34VECTOR QValueVector
+ #define QT34VECTOR TQValueVector
#endif
@@ -56,10 +56,10 @@ namespace LCHMBookIcons
typedef struct
{
//! Entry name
- QString name;
+ TQString name;
//! Entry URLs. The TOC entry should have only one URL; the index entry could have several.
- QStringList urls;
+ TQStringList urls;
//! Associated image number. Used for TOC only; indexes does not have the image.
//! Use LCHMFile::getBookIconPixmap() to get associated pixmap icon
@@ -91,7 +91,7 @@ class LCHMFile
* this one are present locally (like MSDN).
* \ingroup init
*/
- bool loadFile( const QString& archiveName );
+ bool loadFile( const TQString& archiveName );
/*!
* \brief Closes all the files, and frees the appropriate data.
@@ -104,7 +104,7 @@ class LCHMFile
* \return The name of the opened document, or an empty string if no .chm has been loaded.
* \ingroup information
*/
- QString title() const;
+ TQString title() const;
/*!
* \brief Gets the URL of the default page in the chm archive.
@@ -113,7 +113,7 @@ class LCHMFile
* returns "/".
* \ingroup information
*/
- QString homeUrl() const;
+ TQString homeUrl() const;
/*!
* \brief Checks whether the Table of Contents is present in this file.
@@ -161,7 +161,7 @@ class LCHMFile
bool parseIndex( QT34VECTOR< LCHMParsedEntry > * indexes ) const;
/*!
* \brief Retrieves the content from url in current chm file to QString.
* \param str A string where the retreived content should be stored.
* \param url An URL in chm file to retreive content from. Must be absolute.
* \return true if the content is successfully received; false otherwise.
@@ -173,10 +173,10 @@ class LCHMFile
* \sa setCurrentEncoding() currentEncoding() getFileContentAsBinary()
* \ingroup dataretrieve
*/
- bool getFileContentAsString( QString * str, const QString& url );
+ bool getFileContentAsString( TQString * str, const TQString& url );
/*!
* \brief Retrieves the content from url in current chm file to QByteArray.
* \param data A data array where the retreived content should be stored.
* \param url An URL in chm file to retreive content from. Must be absolute.
* \return true if the content is successfully received; false otherwise.
@@ -187,7 +187,7 @@ class LCHMFile
* \sa getFileContentAsString()
* \ingroup dataretrieve
*/
- bool getFileContentAsBinary( QByteArray * data, const QString& url );
+ bool getFileContentAsBinary( TQByteArray * data, const TQString& url );
/*!
* \brief Retrieves the content size.
@@ -197,7 +197,7 @@ class LCHMFile
*
* \ingroup dataretrieve
*/
- bool getFileSize( unsigned int * size, const QString& url );
+ bool getFileSize( unsigned int * size, const TQString& url );
/*!
* \brief Obtains the list of all the files in current chm file archive.
@@ -206,16 +206,16 @@ class LCHMFile
*
* \ingroup dataretrieve
*/
- bool enumerateFiles( QStringList * files );
+ bool enumerateFiles( TQStringList * files );
/*!
* \brief Gets the Title of the HTML page referenced by url.
* \param url An URL in chm file to get title from. Must be absolute.
* \return The title, or QString::null if the URL cannot be found or not a HTML page.
*
* \ingroup dataretrieve
*/
- QString getTopicByUrl ( const QString& url );
+ TQString getTopicByUrl ( const TQString& url );
/*!
* \brief Gets the appropriate CHM pixmap icon.
@@ -224,7 +224,7 @@ class LCHMFile
*
* \ingroup dataretrieve
*/
- const QPixmap * getBookIconPixmap( unsigned int imagenum );
+ const TQPixmap * getBookIconPixmap( unsigned int imagenum );
/*!
* \brief Normalizes the URL, converting relatives, adding "/" in front and removing ..
@@ -233,7 +233,7 @@ class LCHMFile
*
* \ingroup dataretrieve
*/
- QString normalizeUrl( const QString& url ) const;
+ TQString normalizeUrl( const TQString& url ) const;
/*!
* \brief Gets the current CHM archive encoding (set or autodetected)
@@ -270,7 +270,7 @@ class LCHMFile
* If there is no prefix, the word considered as required.
* \ingroup search
*/
- bool searchQuery ( const QString& query, QStringList * results, unsigned int limit = 100 );
+ bool searchQuery ( const TQString& query, TQStringList * results, unsigned int limit = 100 );
//! Access to implementation
LCHMFileImpl * impl() { return m_impl; }
@@ -161,7 +161,7 @@ class LCHMFile
bool parseIndex( QT34VECTOR< LCHMParsedEntry > * indexes ) const;
/*!
- * \brief Retrieves the content from url in current chm file to QString.
+ * \brief Retrieves the content from url in current chm file to TQString.
* \param str A string where the retreived content should be stored.
* \param url An URL in chm file to retreive content from. Must be absolute.
@@ -173,10 +173,10 @@ class LCHMFile
/*!
- * \brief Retrieves the content from url in current chm file to QByteArray.
+ * \brief Retrieves the content from url in current chm file to TQByteArray.
* \param data A data array where the retreived content should be stored.
* \param url An URL in chm file to retreive content from. Must be absolute.
@@ -206,16 +206,16 @@ class LCHMFile
* \brief Gets the Title of the HTML page referenced by url.
* \param url An URL in chm file to get title from. Must be absolute.
- * \return The title, or QString::null if the URL cannot be found or not a HTML page.
+ * \return The title, or TQString() if the URL cannot be found or not a HTML page.
*
* \ingroup dataretrieve